<IBM> is an S4 class specifying one instance of an Individual-Based Model.
It encapsulates all elements required to run the simulation
<IBM> is an S4 class specifying one instance of an Individual-Based Model.
It encapsulates all elements required to run the simulation