Check if units of an object are those expected under a specific context
Source:R/utils.R
check_units_contextual.RdCheck if units of an object are those expected under a specific context
Usage
check_units_contextual(
x,
context = c("length", "weight", "energy", "energy-time", "speed"),
arg = rlang::caller_arg(x),
call = rlang::caller_env()
)