Skip to contents

Estimate energy costs for each state in the profile, given agents condition (e.g. location, bodymass, etc)

Usage

estimate_costs(agent, states_profile, drivers)

Value

A named list, one element for each state id

Examples

TBD
#> Error: object 'TBD' not found