wrapper on slice_strs() to slice density surface with appropriate indices. Slice construction relies on cfg to define the available non-raster dimensions to evaluate
Source: R/simulate_agent_disnbs.R
extract_dns_layer.Rdwrapper on slice_strs() to slice density surface with appropriate indices.
Slice construction relies on cfg to define the available non-raster
dimensions to evaluate