Skip to contents

Calculates slope and aspect of one attribute in the stars object and binds them to the original stars object as attributes

Usage

get_slope_aspect(strs, unit = "radians")

Arguments

strs

A <stars> object.

unit

Optional. A single string indicating units; default is "radians".