Skip to contents

Evaluates consistency amongst components of roamR's IBM initialization function. E.g., asserts that: (i) driver IDs are coherent between specified species configuration and defined drivers; (ii) spatial objects defined in drivers are spatially consistent with defined AOC

Usage

init_check_consistency(
  species,
  drivers,
  model_config = NULL,
  call = rlang::caller_env()
)