<Species> is an S4 class that comprises species-level properties of
simulated agents. It includes attributes related to taxonomy, physiology,
behavioural/activity states, responses to environmental and non-environmental
drivers, and population size.
Slots
idcharacter string, a unique identifier for the species.
common_namecharacter string, the common name of the species.
scientific_namecharacter string, the scientific name of the species.
body_mass_distran object of class VarDist, defining the distribution of body mass for the species.
energy_to_mass_distra VarDist object, providing the energy-to-bodymass conversion rate for the species (e.g. g/kJ). Determines how gained or lost energy translates into changes in body mass.
states_profilea list of State objects, defining the behavioural/activity states for the species to consider in the model.
driver_responseslist of DriverResponse objects, specifying the species’ responses to predefined model drivers, such as environmental pressures, biological influences, and human-induced impacts affecting movement and behaviour/activity states. See DriverResponse for details.
Each element in the
driver_responseslist must correspond to an existing object of class Driver. At the initialization phase of the Individual-Based Model (IBM), thesedriver_responsesare matched with their respective Driver objects to ensure a consistent and well-defined set of species-driver interactions. Failure to provide a corresponding Driver object for each entry ofdriver_responseswill result in missing or undefined driver effects during the simulation.mortality_thresh_distran object of class VarDist, specifying the values of agent's condition (e.g. body mass), below which it is assumed to have died (Note: slot may require further generalization)
pop_sizenumeric, the population size (i.e., number of individuals) within the area of calculation (AOC).
See also
Helper function
Species()to define<Species>objectsHelper functions
VarDist(),DriverResponse()andState()for constructing objects of the dependency classes