Helper function to construct instances of <State> objects, enabling
the specification of attributes specific to an agent's behavioural or
activity state. Each <State> object defines characteristics such as energy
expenditure, time allocation, and movement speed at the individual level.
Arguments
- id
character string, a unique identifier for the state, representing a specific behaviour or activity.
- energy_cost
a <
VarDist> or a <VarFn> object, defining the energy expenditure associated with the state (e.g. kJ/hour/grams).- time_budget
a <
VarDist> object, defining the agent's typical time allocation to this state. It should be expressed as a relative length of time (e.g. hours/day).- speed
a <
VarDist> object, specifying the movement speed associated with this state (e.g. m/s).
Value
a <State> S4 object
See also
VarDist() for defining <VarDist> objects