<VarDist> is an S4 class that encapsulates the distributional properties of
a variable of interest. It allows variables to be defined in terms of their
probability distribution, sampling distribution, percentile distribution or a
fixed value. The class provides a structured approach to specifying input
values by allowing the quantification of uncertainty while ensuring proper
handling of measurement units.
Details
<VarDist> objects extend the functionality of the commendable
distributional package by incorporating
measurement units, ensuring that variable values are interpreted and
processed correctly during simulation calculations.
Slots
distran object of class
<distribution>. Specifies the distribution of values of the variable, representing its expected value and uncertainty/variability.unitsa character string, defining the measurement units of the variable. Must be either a name (e.g.
"grams") or a symbol (e.g."m/s") that recognized by the "udunits" database (seeunits::valid_udunits()). IfNULL(default) the variable is assumed to be unitless.
See also
Helper function
VarDist()to construct<VarDist>objects.Package distributional for access to and details on a comprehensive selection of distributions.