Construct an instance of a <VarFn> object, which declares the
functional properties of a variable of interest to be used in the IBM
simulation.
Arguments
- fn
a function, providing the functional relationship between a model variable (the function's output) and its predicting factors (the function's arguments). Note: Default argument values in
fnare ignored. Values for inputs must be provided viaargs_spec.- args_spec
a list containing <
ArgSpec> objects and/orname = valuepairs, one for each argument offn. See Details for shortcuts to facilitate the specification of different types of<ArgSpec>.- units
character string defining the output units of
fn. Units must be recognized by theunits::valid_udunits()database.- fn_cmp
a compiled version
fn, resulting from applying e.g.build_cost_fn()tofn.
Details
A <VarFn> object declares the relationship between a response variable and
its explanatory variables, allowing to define model variables that are
dependent on the
See also
ArgSpec() for creating <ArgSpec> objects.