<VarFn> is an S4 class that declares the functional properties of a
variable of interest to be used in the IBM simulation.
Details
It enables the specification of a variable as a function of one or more
predictors through an expression, thereby describing the relationship between
the variable and its explanatory factors. This provides a structured approach
to incorporating dynamic dependencies between model components. This class
extends from the VarDist class, inheriting its slots.
Slots
fna function, providing the functional relationship between a model variable and predicting factors.
args_speca list of <
ArgSpec> objects, one for each argument offn.unitscharacter string defining the output units of
fn. Units must be recognized by theunits::valid_udunits()database.fn_cmpcompiled version
fn, resulting from applying e.g.build_cost_fn()tofn.
See also
Helper function VarFn() to construct <VarFn> objects.