Internal function operator for manufacturing functions to calculate energetic costs associated with states based on a user-defined base function. This function interprets the arguments of the base function, and works out the features to construct a function that can be used in the model. The returned manufactured function is a wrapper of the original (base) function that can be used within the package infrastructure. It's arguments are fixed and provide the required objects to compute or extract the input values for the original function.