Estimate energy costs for each state in the profile, given agents condition (e.g. location, bodymass, etc)
Source:R/simulate_agent_disnbs.R
estimate_costs.RdEstimate energy costs for each state in the profile, given agents condition (e.g. location, bodymass, etc)