Calculates slope and aspect of one attribute in the stars object and binds them to the original stars object as attributes
Source:R/rmr_initiate.R
get_slope_aspect.RdCalculates slope and aspect of one attribute in the stars object and binds them to the original stars object as attributes