Introspects <stars> objects from the stars_obj argument of Driver()
Source: R/driver_introspect_stars.R
introspect_stars.RdInternal helper used during the construction of <Drivers> objects via
Driver() to perform validation checks and extract dimensional metadata from
the <stars> object specified to stars_obj. The collected metadata is
required for subsequent internal model use, and is intended to be stored in
slot @stars_meta of <Driver> objects.
Usage
introspect_stars(x, arg = rlang::caller_arg(x), call = rlang::caller_env())Details
Important Note: checks enforced here are specific to the object
construction phase within Driver(). Additional lower-level validation on
stars_obj inputs is handled by the dedicated S4 class validator.