Sets up the starting conditions and initial state for the IBM simulation, incorporating species, habitat, structures, and configuration settings.
Arguments
- model_config
an object of class
<ModelConfig>, specifying the primary configuration settings for the IBM (seeModelConfig()).- species
an object of class
<Species>, comprising the species-level characteristics of the simulated agents (seeSpecies())- drivers
...
- quiet
logical, should feedback on initiation progress be prevented from being printed in R console?