Helpers for debugging errors during simulation, specifically:
save_rng(): stores the RNG vector in current environment into an external filerestore_rng(): restores the RNG saved in a file into the current global environment
Usage
save_rng(savefile = tempfile())