A more flexible approach to the dplyr-based stars.slice() method, allowing
for dynamic slicing over multiple dimensions of a <stars> object.
Arguments
- strs
a
<stars>object- dim_along
a integer or character vector specifying the dimensions along which to slice the
<stars>array- ...
integer or character vectors providing the indices or values to slice for each of the dimensions specified in
dim_along. The order must match the order of dimensions indim_along.- .drop
logical, drop dimensions that only have a single index after slicing?